/*
 * IRC - Internet Relay Chat, ircd/m_sanick.c
 * Copyright (C) 1990 Jarkko Oikarinen and
 *                    University of Oulu, Computing Center
 *
 * See file AUTHORS in IRC package for additional names of
 * the programmers.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 1, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 */

#include "channel.h"
#include "config.h"
#include "client.h"
#include "handlers.h"
#include "hash.h"
#include "ircd.h"
#include "ircd_defs.h"
#include "ircd_features.h"
#include "ircd_string.h"
#include "ircd_snprintf.h"
#include "ircd_alloc.h"
#include "list.h"
#include "msg.h"
#include "numeric.h"
#include "numnicks.h"
#include "querycmds.h"
#include "send.h"
#include "s_conf.h"
#include "s_user.h"
#include "s_debug.h"
#include "userload.h"
#include "patchlevel.h"

#include <string.h>
#include <ctype.h>
#include <stdlib.h>

/*
 * m_sanick - oper message handler
 * parv[0] = sender prefix
 * parv[1] = Target numeric
 * parv[2] = New nickname
 */
int m_sanick(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  struct Client* acptr = NULL;
  struct Client* acptr2 = NULL;

  if(parc<3)
    return(need_more_params(sptr, "SANICK"));

  /* Ignore SANICK for a user that has quit */
  if(!(acptr = FindClient(parv[1])))
    return 0;

  /* Nick already set to what SANICK wants, ignoring... */
  if(ircd_strcmp(cli_name(acptr), parv[2])==0)
    return 0;

  /* Nick collision occured */
  if((acptr2 = FindClient(parv[2]))) {
    send_reply(sptr, ERR_NICKNAMEINUSE, cli_name(acptr2));
    return 0;
  }

  set_nick_name(acptr, acptr, parv[2], parc, parv);
  sendto_opmask_butone(0, SNO_OLDSNO, "%s used SANICK on %s changing nickname to %s", cli_name(cptr), parv[1], parv[2]);
  if (!IsServer(cptr)) {
    sendcmdto_serv_butone(sptr, CMD_SANICK, cptr, "%s %s", parv[1], parv[2]);
  }
  return 0;
}
